0.9.9 API documentation: GLM_GTC_color_space

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTC_color_space
Recommended extensions

Include <glm/gtc/color_space.hpp> to use the features of this extension. More...

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | convertLinearToSRGB (vec< L, T, Q > const &ColorLinear)
| Convert a linear color to sRGB color using a standard gamma correction. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | convertLinearToSRGB (vec< L, T, Q > const &ColorLinear, T Gamma)
| Convert a linear color to sRGB color using a custom gamma correction. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | convertSRGBToLinear (vec< L, T, Q > const &ColorSRGB)
| Convert a sRGB color to linear color using a standard gamma correction. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | convertSRGBToLinear (vec< L, T, Q > const &ColorSRGB, T Gamma)
| Convert a sRGB color to linear color using a custom gamma correction.

## Detailed Description

Include <glm/gtc/color_space.hpp> to use the features of this extension.

Allow to perform bit operations on integer values

## Function Documentation

GLM_FUNC_DECL vec<L, T, Q> glm::convertLinearToSRGB | ( | vec< L, T, Q > const & | ColorLinear | ) |

Convert a linear color to sRGB color using a standard gamma correction.

IEC 61966-2-1:1999 / Rec. 709 specification https://www.w3.org/Graphics/Color/srgb

GLM_FUNC_DECL vec<L, T, Q> glm::convertLinearToSRGB | ( | vec< L, T, Q > const & | ColorLinear,
|  | T | Gamma
| ) |  |

Convert a linear color to sRGB color using a custom gamma correction.

IEC 61966-2-1:1999 / Rec. 709 specification https://www.w3.org/Graphics/Color/srgb

GLM_FUNC_DECL vec<L, T, Q> glm::convertSRGBToLinear | ( | vec< L, T, Q > const & | ColorSRGB | ) |

Convert a sRGB color to linear color using a standard gamma correction.

IEC 61966-2-1:1999 / Rec. 709 specification https://www.w3.org/Graphics/Color/srgb